/* Draw.java - Copyright (c) 2000 Ilpo Jrvinen
 */

package AWTaddon;					// this might be useful class later too...
import	java.awt.Graphics;


/********************************************************************
 * Class Draw is Graphics addon library.
 *
 * @author	Ilpo Jrvinen	<ijjarvin@cs.helsinki.fi>
 * @version	1.01f
 */

/*
 * TODO: clean up the line delta calculations, they look horrible.
 */

public final class Draw {

	private Draw() {}			// Don't allow this class to instanciated
	
	/*
	 * allow inlining, if compiler is capable of doing that.
	 */
	private static int max( int a, int b )		{ return (a > b) ? a : b; }
	private static int abs( int a )				{ return (a >= 0) ? a : -a; }	

	/**********************************************************************
	 * Draws line between x1,y1 and x2,y2 using Graphics g. The line
	 * is not continuos but instead is split into blocks which length
	 * is decided with brokeness parameter.
	 *
	 * @param	g			Graphics for drawing
	 * @param	x1			x coordinate of point 1.
	 * @param	y1			y coordinate of point 1.
	 * @param	x2			x coordinate of point 2.
	 * @param	y2			y coordinate of point 2.
	 * @param	brokeness	size of "lineblock".
	 */
	public static void drawBrokenLine(  Graphics g,
										int x1, int y1, 
										int x2, int y2, 
										int brokeness )
	{
		int		dx = x2 - x1, cx = 0, tx;
		int		dy = y2 - y1, cy = 0, ty;
		double	k = (double)dy / dx;			// +Inf & -Inf included!
		int		c = 0;

		if (brokeness < 1)
			throw new IllegalArgumentException( "brokeness < 0" );
			
		do {
			if (abs(dx) >= abs(dy)) {
				tx = cx + (brokeness-1) * (dx < 0 ? -1 : 1);
				ty = (int)(tx * k);
				g.drawLine( x1 + cx, y1 + cy, x1 + tx, y1 + ty );
				cx += brokeness * 2 * (dx < 0 ? -1 : 1);
				cy = (int)(cx * k);
			} else {
				ty = cy + (brokeness-1) * (dy < 0 ? -1 : 1);
				tx = (int)(ty / k);
				g.drawLine( x1 + cx, y1 + cy, x1 + tx, y1 + ty );
				cy += brokeness * 2 * (dy < 0 ? -1 : 1);
				cx = (int)(cy / k);
			}
		} while( abs(cx) < abs(dx) || abs(cy) < abs(dy) );
	}
}