/* ScrollbalValue.java - Copyright (c) 2000 Ilpo Jrvinen
 * 
 * TiRa Harjoitusty Kevt 2000
 * 
 */

package	AWTaddon;			// this might have some use later too... :)
import	java.awt.*;
import	java.awt.event.*;


/**********************************************************************
 * This class creates an Scrollbar, value TextField and Label for it.
 * Class itself is a Panel which contains all of components.
 *
 * @author	Ilpo Jrvinen <ijjarvin@cs.helsinki.fi>
 * @version	0.6
 */
public class ScrollbarValue extends Panel implements AdjustmentListener, 
											KeyListener, FocusListener {

	private	TextField	valueField = null;
	private Scrollbar 	bar = null;


	/**************************************************************************
	 * Constructs the scrollbar and value, it's recommended that the scrollbar
	 * is horizontal.
	 *
	 * @param name			label of the scrollbar
	 * @param orientation	orientation of the scrollbar (rec: horiz)
	 * @param value			default value of the scrollbar
	 * @param visible		size of scrollbar's "bubble"
	 * @param minimum		minimum value of the scrollbar
	 * @param maximum		maximum value of the scrollbar
	 */
	public ScrollbarValue( String name, int orientation, int value, int visible, 
							int minimum, int maximum )
	{
		bar = new Scrollbar( orientation, value, visible, minimum, maximum );
		setLayout( new GridLayout( 3, 1 ) );
		buildPanel( name );
	}
	

	/*********************************************************************
	 * This method adds components to the Panel and initializes Listeners.
	 */
	private	void buildPanel( String name )
	{
		valueField = new TextField();
		valueField.setText(""+bar.getValue());
		add(new Label( name, Label.CENTER ) );
		add(valueField );
		add(bar );
		
		bar.addAdjustmentListener(this);
		valueField.addKeyListener(this);
		valueField.addFocusListener(this);
	}
	
	
	/*
	 * Because this is not a subclass of Scrollbar all scrollbar
	 * methods should be implemented and redirected to correct destination.
	 * This is currently partially supported.
	 */
	 
	/******************************************
	 * @return value of the scrollbal.
	 */
	public int	getValue()			{ return bar.getValue(); }


	/* ****************************************************************
	 * All methods below do the valueField and scrollbar synchronization.
	 */

	/*******************************************
	 * Scrollbar and Textfield syncronizer.
	 * Scrollbar gets tuned. Value in Field is change.
	 */
	public void adjustmentValueChanged( AdjustmentEvent e )
	{
		valueField.setText(""+bar.getValue());
	}
	
	/*******************************************
	 * Scrollbar and Textfield syncronizer.
	 * When user types a new value to field the scrollbar is changed
	 * accordingly, if value is out of limits the scrollbar will be set to
	 * the closest bound.
	 */
	public void keyTyped( KeyEvent e ) 
	{
		/* The event should be activated, but I don't know how... :(
		 * I did a hack instead.
		 */
		String val = valueField.getText().trim();
		if (e.getKeyChar() == '\b' ) {
			if (val.length() > 0)
				val = val.substring(0, val.length() - 1);
		} else {
			val = (val+e.getKeyChar()).trim();
		}
		int i = bar.getValue();
		try {
			i = Integer.parseInt( val );
		} catch (Exception exc) {
//			System.out.println( exc );			// debug
		}
		if (i < bar.getMinimum())
			i = bar.getMinimum();
		if (i >= bar.getMaximum())
			i = bar.getMaximum() - 1;
		bar.setValue(i);
	}


	
	/*******************************************************************
	 * Scrollbar and Textfield syncronizer.
	 * When textField losses its focus, the value of the scrollbar will be
	 * copied to it if value isn't inside the correct range.
	 * This isn't always the best way to handle this, this may change
	 * later.
	 */
	public void focusLost( FocusEvent e )
	{
		try {
			int i = Integer.parseInt( valueField.getText().trim() );
			if (i < bar.getMinimum() || i >= bar.getMaximum() );
			valueField.setText( ""+bar.getValue() );
		} catch (Exception exc) {
			valueField.setText( ""+bar.getValue() );
		}
	}


	/*
	 * Dummy interface requirements.
	 */
	public void keyPressed( KeyEvent e ) {}
	public void keyReleased( KeyEvent e ) {}
	public void focusGained( FocusEvent e ) {}	

}
