/* GenerateDialog.java - Copyright (c) Ilpo Jrvinen
 *
 * TiRa harjoitusty K2000
 */

import	AWTaddon.*;
import	java.awt.*;
import	java.awt.event.*;


/************************************************************************
 * This class creates a dialog which queryes size of map to be generated
 * from user.
 *
 * @author 	Ilpo Jrvinen <ijjarvin@cs.helsinki.fi>
 * @version	0.99f
 */
public class GenerateDialog extends Dialog implements ActionListener, 
														WindowListener {

	public static final int 	DEFAULTX = 30,
								DEFAULTY = 20;
	private Button				ok = null,
								cancel = null;
	private ScrollbarValue		xSize = null,
								ySize = null;
						
	private boolean cancelled = true;

	/*********************************************
	 * Constructs the dialog.
	 *
	 * @param owner	The dialogs parent window.
	 */
	public GenerateDialog( Frame owner )
	{
		super( owner, "Generate...", true );
		
		Panel scrollers = new Panel();
		scrollers.setLayout(new BorderLayout());
		xSize = new ScrollbarValue( "X size", Scrollbar.HORIZONTAL, DEFAULTX, 1, 1, 100 );
		ySize = new ScrollbarValue( "Y size", Scrollbar.HORIZONTAL, DEFAULTY, 1, 1, 100 );
		scrollers.add( "North", xSize );
		scrollers.add( "South", ySize );
		add( "Center", scrollers );
		
		Panel buttons = new Panel();
		buttons.setLayout(new FlowLayout(FlowLayout.RIGHT));
		ok = new Button( "OK" );
		ok.addActionListener(this);
		Button cancel = new Button( "Cancel" );
		cancel.addActionListener(this);
		buttons.add(ok);
		buttons.add(cancel);
		add( "South", buttons );
		
		pack();							// resize to optimal...
		setResizable(false);			// don't mess with it... ;) X-window cannot guarantee this... :(
		addWindowListener( this );		// close should work?
	}				
	

	/*****************************************
	 * This method handles button events.
	 */
	public void actionPerformed(ActionEvent e)
	{
		Object source = e.getSource();
		if (source == ok) {
			cancelled = false;
		}
		setVisible( false );
	}
	
	/** @return x value of scrollbar assisiated to it. */
	public int getXValue()		{ return xSize.getValue(); }
	/** @return y value of scrollbar assosiated to it. */
	public int getYValue()		{ return ySize.getValue(); }
	/** @return false if operation was cancelled. */
	public boolean	getOk()		{ return !cancelled; }
	

	/*********************
	 * Dialog close.
	 */
	public void windowClosing(WindowEvent e) 
	{
		setVisible( false );
	}

	/*
	 * Dummy interface methods.
	 */
	public void windowActivated(WindowEvent e) {}
	public void windowClosed(WindowEvent e) {}
	public void windowDeactivated(WindowEvent e) {}
	public void windowDeiconified(WindowEvent e) {}
	public void windowIconified(WindowEvent e) {}
	public void windowOpened(WindowEvent e) {}

}
