/* List.java - Copyright (c) 2000 Ilpo Jrvinen
 *
 * TiRa harjoitusty K2000
 */

import java.util.Enumeration;
import java.util.NoSuchElementException;


/********************************************************************
 * List is implementation of LinkedList. The list consists chain of 
 * ListNodes. The List itself is a header node for the list.
 * 
 * @author	Ilpo Jrvinen <ijjarvin@cs.helsinki.fi> 
 * @version	0.8f
 */
public class List extends ListNode {


	private int		size = 0;
	

	/**********************************************************************
	 * Constructs an empty list.
	 */
	public List()
	{
		super( null, null );
	}
	

	/*********************************************************************
	 * Inserts Object o to specified index into list. If index is "out of 
	 * bounds", it will be set to the value of the closest bound.
	 *
	 * @param	o		element to be inserted.
	 * @param	index	the specified index.
	 */
	public void insert( Object o, int index )
	{
		if (index < 0)
			index = 0;
		if (index > size)
			index = size;
			
		ListNode ptr = this;
		while (index-- > 0)
			ptr = ptr.next;

		size++;
		ptr.addAfter( o );
	}


	/******************************************************
	 * @return the number of elements in List.
	 */
	public int		size()				{ return size; }
	
	
	/****************************************************
	 * This method returns the nth element.
	 *
	 * @param	n	index of the requested element.
	 */
	public Object get( int n )
	{
		if (n < 0)
			throw new NoSuchElementException();
		Enumeration e = elements();
		while (n-- > 0 && e.hasMoreElements())
			e.nextElement();
		return e.nextElement();				// if n is too large
	}

	/***************************************************************
	 * This is _not_ synchronized nor remove-safe iterator!
	 * @see java.util.Enumeration
	 */	
	private class Iter implements Enumeration {
		private ListNode	curr;
		private Iter( List l ) 				{ curr = l.next; }
		public boolean hasMoreElements()	{ return curr != null; }
		public Object nextElement()			
		{
			if (curr == null)
				throw new NoSuchElementException();
			Object r = curr.data;
			curr = curr.next;
			return r;
		}
	}


	/*************************************************************
	 * @return	iterator for scanning through the list.
	 */
	public Enumeration elements()
	{
		return new Iter( this );
	}


	/*
	 * DEBUG ONLY!
	 */	
	public String toString()
	{
		StringBuffer ret = new StringBuffer( "|-" );
		for (Enumeration e = elements(); e.hasMoreElements();) {
			ret.append( e.nextElement().toString() );
			ret.append( e.hasMoreElements() ? "->" : "-||" );
		}
		return ret.toString();
	}
}


/*******************************************************************
 * Storage class. Also some simple ops are implemented here.
 */
class ListNode {
	Object data;
	ListNode next;
		
	protected ListNode( Object d, ListNode n )	{ data = d; next = n; }
	protected ListNode( Object d )				{ data = d; }
	protected ListNode()						{ data = null; next = null; }
	
	
	/*****************************************************
	 * Removes node after this.
	 *
	 * @return	the removed element.
	 */
	protected Object removeNext()
	{
		Object r = next.data;
		next = next.next;
		return r;
	}

	/**********************************
	 * Adds node for o after this.
	 *
	 * @param	o	element to be added.
	 */	
	protected void addAfter( Object o )
	{
		next = new ListNode( o, next );
	}
}
