/* Path.java - Copyright (c) 2000 Ilpo Jrvinen
 *
 * TiRa harjoitusty K2000
 */

import	java.util.Enumeration;


/***************************************************************************
 * This is very simple class which only "renames" some List operations and
 * creates a shortcut to first and last items in List.
 *
 * @author	Ilpo Jrvinen <ijjarvin@cs.helsinki.fi>
 * @version	0.92
 */
public class Path {

	private List		path = new List();
	private	boolean		ok;
	private double		length;


	/************************************************************
	 * @param	len		length of this path.
	 */
	protected Path( double len ) 
	{
		ok = (len >= 0);
		length = len;
	}
	
	
	/************************************************************
	 * This method adds points to this path.
	 *
	 * @param	p	point to be added.
	 */
	protected void addPoint( Point p )
	{
		path.insert( p, 0 );
	}
	
	
	/********************************************
	 * Queryes start or endpoint of this path.
	 *
	 * @param	start	true for startpoint, false for endpoint
	 *
	 * @return	requested point.
	 */
	public Point endPoint( boolean start ) 
	{
		return (Point)path.get( start ? 0 : path.size() - 1 ); 
	}
	

	/***********************************************
	 * @return the validity of this path.
	 */
	public boolean hasPath() { return ok; }	
	
	/***********************************************
	 * @return length of the path
	 */
	public double getLength() { return length; }

	/***********************************************
	 * @return	Enumeration of this path.
	 */
	public Enumeration elements() {
		return path.elements();
	}


	/*
	 * DEBUG ONLY!
	 */
	public String toString()
	{
		String s = "";
		for (Enumeration e = path.elements(); e.hasMoreElements(); )
		{
			Object o = e.nextElement();
			s += o.toString();
		}
		return s;
	}
}
