/* Point.java - Copyright (c) 2000 Ilpo Jrvinen
 *
 * TiRa harjoitusty K2000
 */

/********************************************************************
 * Class Point is storage class used for storing coordinates x and y
 *
 * @author	Ilpo Jrvinen <ijjarvin@cs.helsinki.fi>
 * @version	1.0f
 */
public class Point {
	private int x, y;
	

	/***************************************************************
	 * @param	x	the x coordinate for this point.
	 * @param	y	the y coordinate for this point.
	 */	
	protected Point( int x, int y )
	{
		this.x = x;
		this.y = y;
	}
	

	/***************************************************************
	 * @param	another	An another Point.
	 * @return	true if Points are equal.
	 *
	 * @throw	ClassCastException	if another is not a instance of Point.
	 */
	public boolean equals( Object another )
	{
		if (this == another)
			return true;
		Point t = (Point)another;
		return (x == t.x) && (y == t.y);
	}
	
	
	/****************************************
	 * @return	The x coordinate of this point.
	 */
	public int getX()				{ return x; }
	/****************************************
	 * @return	The y coordinate of this point.
	 */
	public int getY()				{ return y; }
	
	
	/****************************************
	 * @param	another		another point.
	 * @return	The x distance between another and this point.
	 */	
	public int xDiff( Point another )		{ return Math.abs(another.x - x); }
	/****************************************
	 * @param	another		another point.
	 * @return	The y distance between another and this point.
	 */
	public int yDiff( Point another )		{ return Math.abs(another.y - y); }
	
	
	/*************************************************
	 * @return String representation of this point.
	 */
	public String toString()
	{
		StringBuffer t = new StringBuffer();
		t.append( '(' ).append(x).append(',').append(' ').append(y).append(')');
		return t.toString();
	}

}
