/* Robot.java - Copyright (c) 2000 Ilpo Jrvinen
 *
 * TiRa harjoitusty K2000
 */

import	java.awt.*;
import	java.awt.event.*;
import	java.io.*;


public class Robot extends Frame implements ActionListener {

	/*
	 * GUI definations...
	 */
	private MenuBar				menubar = new MenuBar();
	private	Menu				file = new Menu( "File" );
	
	private MenuItem			load = new MenuItem( "Load..." );
	private MenuItem			generate = new MenuItem( "Generate..." );
	private MenuItem			save = new MenuItem( "Save..." );
	private MenuItem			quit = new MenuItem( "Quit" );

	private ScrollPane			scroll = null;
	private	Field 				field = null;		// ...our playground... ;)


	/**********************************************************************
	 * Builds the GUI which is basicly a Scrollpane in which the
	 * Canvas displays the current map.
	 */
	public Robot() 
	{
		addWindowListener(new TerminateRobot());	// terminate graciously

		message( null );
		initMenus();

		setLayout( new BorderLayout() );			// this should be default but I don't thrust JAVA a bit.
		scroll = new ScrollPane( ScrollPane.SCROLLBARS_AS_NEEDED );
		scroll.setSize(600,400);
		field = new Field( this );
		scroll.add( "West", field );
		add( scroll );
		
		pack();										// optimize size...
		setVisible(true);
		
	}


	/*************************************************************
	 * GUI menu builder... separated from constructor...
	 */	
	private void initMenus()
	{
		file.add( load );							// file menu
		file.add( generate );
		file.addSeparator();
		file.add( save );
		file.addSeparator();
		file.add( quit );		
		menubar.add( file );

		quit.addActionListener( this );				// menu actions
		generate.addActionListener( this );
		load.addActionListener( this );
		save.addActionListener( this );

		setMenuBar( menubar );						// menubar to screen
	}


	/******************************************************
	 * Inserts message to titlebar
	 *
	 * @param	s	message.
	 */
	public void message( String s )
	{
		if (s == null)
			s = "";
		if (s.length() < 1)
			setTitle( "Robot" );
		else
			setTitle( "Robot - " + s );
	}


	/***********************************************************************
	 * This is a hack to fix scrollbars when content of
	 * the scrollpane is changed (actually the change of the size is the
	 * real killer, not the change of content).
	 */
	public void scrollpaneHack()
	{
		remove( scroll );			// Java hack to fix the scrollpane
		add( scroll );				// when Field is resized!
		pack();						// TESTME! setVisible(true);??? Didn't work.
	}
	
	
	/***************************************************************
	 * Menuitem event redirector, redirects to Field.
	 */
	public void actionPerformed(ActionEvent e) 
	{
		Object src = e.getSource();

		if (src == quit) {					// quit menuitem
			System.exit(0);
		} else if (src == generate) {		// generate menuitem
			field.generate();
			scrollpaneHack();
		} else if (src == load) {			// load menuitem
			field.load();			
			scrollpaneHack();
		} else if (src == save) {			// save menuitem
			field.save();
		} else {
//			System.out.println( e );		// debug
		}
	}


	/****************************************************************
	 * As simple as possible.
	 */
	public static void main(String[] args) {
		Robot window = new Robot();
	}

}


/*
 * The main windows close function requires this.
 * Simply terminates the application.
 */
class TerminateRobot extends WindowAdapter {
	public void windowClosing(WindowEvent event) {
		System.exit(0);
	}
}

